@@ -356,7 +356,20 @@ DOCUMENTATION__applications = SwaggerDocumentation(
             name="Add application",
             description="Add a new application",
             method=REST__POST,
-            body=ARG_RES__application_body + [ARG_RES__public_username]
+            body=ARG_RES__application_body + [
+                ARG_RES__public_username,
+                SwaggerArgumentResponse(
+                    name=KEY__default_database,
+                    description="A default database if provided. Will create default configurations giving access to this and set the public user as "
+                                "a default role and set the precedence of the public user to -1 so there are no precedence clashes. Please use the "
+                                "format 'node/dbname' for input for example 'host/jaaql'. If no node is provided, the node is assumed as 'host'. "
+                                "The database will be created if the host exists and the database does not exist. ",
+                    arg_type=str,
+                    example=["host/jaaql"],
+                    required=False,
+                    condition="Is a default database supplied"
+                )
+            ]
         ),
         SwaggerMethod(
             name="Fetch applications",
@@ -895,7 +908,6 @@ ARG_RES__email_account_name = SwaggerArgumentResponse(
     example=EXAMPLE__email_account_name
 )
 
-KEY__email_account_send_name = "send_name"
 EXAMPLE__email_account_send_name = "JAAQL Admin"
 ARG_RES__email_account_send_name = SwaggerArgumentResponse(
     name=KEY__email_account_send_name,
@@ -908,25 +920,25 @@ ARG_RES__email_account_base = [
     ARG_RES__email_account_name,
     ARG_RES__email_account_send_name,
     SwaggerArgumentResponse(
-        name="protocol",
+        name=KEY__email_account_protocol,
         description="The sending protocol. One of 'smtp', 'imap'",
         arg_type=str,
         example=["smtp", "imap"]
     ),
     SwaggerArgumentResponse(
-        name="host",
+        name=KEY__email_account_host,
         description="The host of the email server",
         arg_type=str,
         example=["smtp.gmail.com"]
     ),
     SwaggerArgumentResponse(
-        name="port",
+        name=KEY__email_account_port,
         description="The port of the email server",
         arg_type=int,
         example=[587]
     ),
     SwaggerArgumentResponse(
-        name="username",
+        name=KEY__email_account_username,
         description="The username to authenticate with the email server",
         arg_type=str,
         example=["user@gmail.com"]
@@ -1023,6 +1035,13 @@ ARG_RES__email_template_body = [
         required=False,
         condition="Is this parameter specified"
     ),
+    SwaggerArgumentResponse(
+        name=KEY__allow_reset_password,
+        description="Allow this email to be sent to the user if they have forgotten their password",
+        arg_type=bool,
+        required=False,
+        condition="Is this parameter specified"
+    ),
     SwaggerArgumentResponse(
         name=KEY__data_validation_table,
         description="A table that is used for data validation. A row is inserted into this table with the "
@@ -1099,3 +1118,13 @@ DOCUMENTATION__email_template_confirm_deletion = SwaggerDocumentation(
         body=ARG_RES__deletion_key
     )
 )
+
+DOCUMENTATION__is_alive = SwaggerDocumentation(
+    security=False,
+    tags="Is Alive",
+    methods=SwaggerMethod(
+        name="Check is alive",
+        description="An endpoint that can be called by any service to see if the service is alive",
+        method=REST__GET
+    )
+)
